@@ -4,7 +4,8 @@ from pathlib import Path
 import pydantic
 from ruamel.yaml import YAML, YAMLError
 from ruamel.yaml.scalarstring import FoldedScalarString
-from agentstack import ValidationError
+from agentstack import conf
+from agentstack.exceptions import ValidationError
 
 
 AGENTS_FILENAME: Path = Path("src/config/agents.yaml")
@@ -46,11 +47,8 @@ class AgentConfig(pydantic.BaseModel):
     backstory: str = ""
     llm: str = ""
 
-    def __init__(self, name: str, path: Optional[Path] = None):
-        if not path:
-            path = Path()
-
-        filename = path / AGENTS_FILENAME
+    def __init__(self, name: str):
+        filename = conf.PATH / AGENTS_FILENAME
         if not os.path.exists(filename):
             os.makedirs(filename.parent, exist_ok=True)
             filename.touch()
@@ -69,9 +67,6 @@ class AgentConfig(pydantic.BaseModel):
                 error_str += f"{' '.join([str(loc) for loc in error['loc']])}: {error['msg']}\n"
             raise ValidationError(f"Error loading agent {name} from {filename}.\n{error_str}")
 
-        # store the path *after* loading data
-        self._path = path
-
     def model_dump(self, *args, **kwargs) -> dict:
         dump = super().model_dump(*args, **kwargs)
         dump.pop('name')  # name is the key, so keep it out of the data
@@ -81,7 +76,7 @@ class AgentConfig(pydantic.BaseModel):
         return {self.name: dump}
 
     def write(self):
-        filename = self._path / AGENTS_FILENAME
+        filename = conf.PATH / AGENTS_FILENAME
 
         with open(filename, 'r') as f:
             data = yaml.load(f) or {}
@@ -98,10 +93,8 @@ class AgentConfig(pydantic.BaseModel):
         self.write()
 
 
-def get_all_agent_names(path: Optional[Path] = None) -> list[str]:
-    if not path:
-        path = Path()
-    filename = path / AGENTS_FILENAME
+def get_all_agent_names() -> list[str]:
+    filename = conf.PATH / AGENTS_FILENAME
     if not os.path.exists(filename):
         return []
     with open(filename, 'r') as f:
@@ -109,5 +102,5 @@ def get_all_agent_names(path: Optional[Path] = None) -> list[str]:
     return list(data.keys())
 
 
-def get_all_agents(path: Optional[Path] = None) -> list[AgentConfig]:
-    return [AgentConfig(name, path) for name in get_all_agent_names(path)]
+def get_all_agents() -> list[AgentConfig]:
+    return [AgentConfig(name) for name in get_all_agent_names()]
