@@ -1,21 +1,14 @@
-import json
-import shutil
+from typing import Optional
+import os
 import sys
 import time
 from datetime import datetime
-from typing import Optional
-from pathlib import Path
-import requests
-import itertools
 
+import json
+import shutil
 from art import text2art
 import inquirer
-import os
-import importlib.resources
 from cookiecutter.main import cookiecutter
-from dotenv import load_dotenv
-import subprocess
-from packaging.metadata import Metadata
 
 from .agentstack_data import (
     FrameworkData,
@@ -24,17 +17,18 @@ from .agentstack_data import (
     CookiecutterData,
 )
 from agentstack.logger import log
+from agentstack import conf
+from agentstack.conf import ConfigFile
 from agentstack.utils import get_package_path
-from agentstack.tools import get_all_tools
-from agentstack.generation.files import ConfigFile, ProjectFile
+from agentstack.generation.files import ProjectFile
 from agentstack import frameworks
-from agentstack import packaging
 from agentstack import generation
+from agentstack import inputs
 from agentstack.agents import get_all_agents
 from agentstack.tasks import get_all_tasks
-from agentstack.utils import open_json_file, term_color, is_snake_case, get_framework
-from agentstack.update import AGENTSTACK_PACKAGE
+from agentstack.utils import open_json_file, term_color, is_snake_case, get_framework, validator_not_empty
 from agentstack.proj_templates import TemplateConfig
+from agentstack.exceptions import ValidationError
 
 
 PREFERRED_MODELS = [
@@ -52,16 +46,13 @@ def init_project_builder(
     use_wizard: bool = False,
 ):
     if not slug_name and not use_wizard:
-        print(term_color("Project name is required. Use `agentstack init <project_name>`", 'red'))
-        return
+        raise Exception("Project name is required. Use `agentstack init <project_name>`")
 
     if slug_name and not is_snake_case(slug_name):
-        print(term_color("Project name must be snake case", 'red'))
-        return
+        raise Exception("Project slug name must be snake_case")
 
     if template is not None and use_wizard:
-        print(term_color("Template and wizard flags cannot be used together", 'red'))
-        return
+        raise Exception("Template and wizard flags cannot be used together")
 
     template_data = None
     if template is not None:
@@ -123,9 +114,12 @@ def init_project_builder(
 
     log.debug(f"project_details: {project_details}" f"framework: {framework}" f"design: {design}")
     insert_template(project_details, framework, design, template_data)
-    path = Path(project_details['name'])
+
+    # we have an agentstack.json file in the directory now
+    conf.set_path(project_details['name'])
+
     for tool_data in tools:
-        generation.add_tool(tool_data['name'], agents=tool_data['agents'], path=path)
+        generation.add_tool(tool_data['name'], agents=tool_data['agents'])
 
 
 def welcome_message():
@@ -141,9 +135,9 @@ def welcome_message():
     print(border)
 
 
-def configure_default_model(path: Optional[str] = None):
+def configure_default_model():
     """Set the default model"""
-    agentstack_config = ConfigFile(path)
+    agentstack_config = ConfigFile()
     if agentstack_config.default_model:
         return  # Default model already set
 
@@ -158,31 +152,10 @@ def configure_default_model(path: Optional[str] = None):
         print('A list of available models is available at: "https://docs.litellm.ai/docs/providers"')
         model = inquirer.text(message="Enter the model name")
 
-    with ConfigFile(path) as agentstack_config:
+    with ConfigFile() as agentstack_config:
         agentstack_config.default_model = model
 
 
-def run_project(framework: str, path: str = ''):
-    """Validate that the project is ready to run and then run it."""
-    if framework not in frameworks.SUPPORTED_FRAMEWORKS:
-        print(term_color(f"Framework {framework} is not supported by agentstack.", 'red'))
-        sys.exit(1)
-
-    _path = Path(path)
-
-    try:
-        frameworks.validate_project(framework, _path)
-    except frameworks.ValidationError as e:
-        print(term_color("Project validation failed:", 'red'))
-        print(e)
-        sys.exit(1)
-
-    load_dotenv(Path.home() / '.env')  # load the user's .env file
-    load_dotenv(_path / '.env', override=True)  # load the project's .env file
-    print("Running your agent...")
-    subprocess.run(['python', 'src/main.py'], env=os.environ)
-
-
 def ask_framework() -> str:
     framework = "CrewAI"
     # framework = inquirer.list_input(
@@ -209,6 +182,75 @@ def ask_framework() -> str:
     return framework
 
 
+def get_validated_input(
+    message: str,
+    validate_func=None,
+    min_length: int = 0,
+    snake_case: bool = False,
+) -> str:
+    """Helper function to get validated input from user.
+
+    Args:
+        message: The prompt message to display
+        validate_func: Optional custom validation function
+        min_length: Minimum length requirement (0 for no requirement)
+        snake_case: Whether to enforce snake_case naming
+    """
+    while True:
+        try:
+            value = inquirer.text(
+                message=message,
+                validate=validate_func or validator_not_empty(min_length) if min_length else None,
+            )
+            if snake_case and not is_snake_case(value):
+                raise ValidationError("Input must be in snake_case")
+            return value
+        except ValidationError as e:
+            print(term_color(f"Error: {str(e)}", 'red'))
+
+
+def ask_agent_details():
+    agent = {}
+
+    agent['name'] = get_validated_input(
+        "What's the name of this agent? (snake_case)", min_length=3, snake_case=True
+    )
+
+    agent['role'] = get_validated_input("What role does this agent have?", min_length=3)
+
+    agent['goal'] = get_validated_input("What is the goal of the agent?", min_length=10)
+
+    agent['backstory'] = get_validated_input("Give your agent a backstory", min_length=10)
+
+    agent['model'] = inquirer.list_input(
+        message="What LLM should this agent use?", choices=PREFERRED_MODELS, default=PREFERRED_MODELS[0]
+    )
+
+    return agent
+
+
+def ask_task_details(agents: list[dict]) -> dict:
+    task = {}
+
+    task['name'] = get_validated_input(
+        "What's the name of this task? (snake_case)", min_length=3, snake_case=True
+    )
+
+    task['description'] = get_validated_input("Describe the task in more detail", min_length=10)
+
+    task['expected_output'] = get_validated_input(
+        "What do you expect the result to look like? (ex: A 5 bullet point summary of the email)",
+        min_length=10,
+    )
+
+    task['agent'] = inquirer.list_input(
+        message="Which agent should be assigned this task?",
+        choices=[a['name'] for a in agents],
+    )
+
+    return task
+
+
 def ask_design() -> dict:
     use_wizard = inquirer.confirm(
         message="Would you like to use the CLI wizard to set up agents and tasks?",
@@ -233,39 +275,10 @@ First we need to create the agents that will work together to accomplish tasks:
     while make_agent:
         print('---')
         print(f"Agent #{len(agents)+1}")
-
-        agent_incomplete = True
         agent = None
-        while agent_incomplete:
-            agent = inquirer.prompt(
-                [
-                    inquirer.Text("name", message="What's the name of this agent? (snake_case)"),
-                    inquirer.Text("role", message="What role does this agent have?"),
-                    inquirer.Text("goal", message="What is the goal of the agent?"),
-                    inquirer.Text("backstory", message="Give your agent a backstory"),
-                    # TODO: make a list - #2
-                    inquirer.Text(
-                        'model',
-                        message="What LLM should this agent use? (any LiteLLM provider)",
-                        default="openai/gpt-4",
-                    ),
-                    # inquirer.List("model", message="What LLM should this agent use? (any LiteLLM provider)", choices=[
-                    #     'mixtral_llm',
-                    #     'mixtral_llm',
-                    # ]),
-                ]
-            )
-
-            if not agent['name'] or agent['name'] == '':
-                print(term_color("Error: Agent name is required - Try again", 'red'))
-                agent_incomplete = True
-            elif not is_snake_case(agent['name']):
-                print(term_color("Error: Agent name must be snake case - Try again", 'red'))
-            else:
-                agent_incomplete = False
-
-        make_agent = inquirer.confirm(message="Create another agent?")
+        agent = ask_agent_details()
         agents.append(agent)
+        make_agent = inquirer.confirm(message="Create another agent?")
 
     print('')
     for x in range(3):
@@ -282,35 +295,9 @@ First we need to create the agents that will work together to accomplish tasks:
     while make_task:
         print('---')
         print(f"Task #{len(tasks) + 1}")
-
-        task_incomplete = True
-        task = None
-        while task_incomplete:
-            task = inquirer.prompt(
-                [
-                    inquirer.Text("name", message="What's the name of this task? (snake_case)"),
-                    inquirer.Text("description", message="Describe the task in more detail"),
-                    inquirer.Text(
-                        "expected_output",
-                        message="What do you expect the result to look like? (ex: A 5 bullet point summary of the email)",
-                    ),
-                    inquirer.List(
-                        "agent",
-                        message="Which agent should be assigned this task?",
-                        choices=[a['name'] for a in agents],  # type: ignore
-                    ),
-                ]
-            )
-
-            if not task['name'] or task['name'] == '':
-                print(term_color("Error: Task name is required - Try again", 'red'))
-            elif not is_snake_case(task['name']):
-                print(term_color("Error: Task name must be snake case - Try again", 'red'))
-            else:
-                task_incomplete = False
-
-        make_task = inquirer.confirm(message="Create another task?")
+        task = ask_task_details(agents)
         tasks.append(task)
+        make_task = inquirer.confirm(message="Create another task?")
 
     print('')
     for x in range(3):
@@ -398,10 +385,13 @@ def insert_template(
         template_version=template_data.template_version if template_data else 0,
     )
 
-    project_structure = ProjectStructure()
+    project_structure = ProjectStructure(
+        method=template_data.method if template_data else "sequential",
+        manager_agent=template_data.manager_agent if template_data else None,
+    )
     project_structure.agents = design["agents"]
     project_structure.tasks = design["tasks"]
-    project_structure.set_inputs(design["inputs"])
+    project_structure.inputs = design["inputs"]
 
     cookiecutter_data = CookiecutterData(
         project_metadata=project_metadata,
@@ -412,6 +402,7 @@ def insert_template(
     template_path = get_package_path() / f'templates/{framework.name}'
     with open(f"{template_path}/cookiecutter.json", "w") as json_file:
         json.dump(cookiecutter_data.to_dict(), json_file)
+        # TODO this should not be written to the package directory
 
     # copy .env.example to .env
     shutil.copy(
@@ -461,54 +452,33 @@ def insert_template(
     )
 
 
-def list_tools():
-    # Display the tools
-    tools = get_all_tools()
-    curr_category = None
-
-    print("\n\nAvailable AgentStack Tools:")
-    for category, tools in itertools.groupby(tools, lambda x: x.category):
-        if curr_category != category:
-            print(f"\n{category}:")
-            curr_category = category
-        for tool in tools:
-            print("  - ", end='')
-            print(term_color(f"{tool.name}", 'blue'), end='')
-            print(f": {tool.url if tool.url else 'AgentStack default tool'}")
-
-    print("\n\n✨ Add a tool with: agentstack tools add <tool_name>")
-    print("   https://docs.agentstack.sh/tools/core")
-
-
-def export_template(output_filename: str, path: str = ''):
+def export_template(output_filename: str):
     """
     Export the current project as a template.
     """
-    _path = Path(path)
-    framework = get_framework(_path)
-
     try:
-        metadata = ProjectFile(_path)
+        metadata = ProjectFile()
     except Exception as e:
         print(term_color(f"Failed to load project metadata: {e}", 'red'))
         sys.exit(1)
 
     # Read all the agents from the project's agents.yaml file
     agents: list[TemplateConfig.Agent] = []
-    for agent in get_all_agents(_path):
+    for agent in get_all_agents():
         agents.append(
             TemplateConfig.Agent(
                 name=agent.name,
                 role=agent.role,
                 goal=agent.goal,
                 backstory=agent.backstory,
+                allow_delegation=False,  # TODO
                 model=agent.llm,  # TODO consistent naming (llm -> model)
             )
         )
 
     # Read all the tasks from the project's tasks.yaml file
     tasks: list[TemplateConfig.Task] = []
-    for task in get_all_tasks(_path):
+    for task in get_all_tasks():
         tasks.append(
             TemplateConfig.Task(
                 name=task.name,
@@ -520,8 +490,8 @@ def export_template(output_filename: str, path: str = ''):
 
     # Export all of the configured tools from the project
     tools_agents: dict[str, list[str]] = {}
-    for agent_name in frameworks.get_agent_names(framework, _path):
-        for tool_name in frameworks.get_agent_tool_names(framework, agent_name, _path):
+    for agent_name in frameworks.get_agent_names():
+        for tool_name in frameworks.get_agent_tool_names(agent_name):
             if not tool_name:
                 continue
             if tool_name not in tools_agents:
@@ -537,26 +507,22 @@ def export_template(output_filename: str, path: str = ''):
             )
         )
 
-    inputs: list[str] = []
-    # TODO extract inputs from project
-    # for input in frameworks.get_input_names():
-    #     inputs.append(input)
-
     template = TemplateConfig(
-        template_version=1,
+        template_version=3,
         name=metadata.project_name,
         description=metadata.project_description,
-        framework=framework,
+        framework=get_framework(),
         method="sequential",  # TODO this needs to be stored in the project somewhere
+        manager_agent=None,  # TODO
         agents=agents,
         tasks=tasks,
         tools=tools,
-        inputs=inputs,
+        inputs=inputs.get_inputs(),
     )
 
     try:
-        template.write_to_file(_path / output_filename)
-        print(term_color(f"Template saved to: {_path / output_filename}", 'green'))
+        template.write_to_file(conf.PATH / output_filename)
+        print(term_color(f"Template saved to: {conf.PATH / output_filename}", 'green'))
     except Exception as e:
         print(term_color(f"Failed to write template to file: {e}", 'red'))
         sys.exit(1)
