@@ -1,4 +1,4 @@
 from .agent_generation import add_agent
 from .task_generation import add_task
 from .tool_generation import add_tool, remove_tool
-from .files import ConfigFile, EnvFile, CONFIG_FILENAME
\ No newline at end of file
+from .files import EnvFile, ProjectFile
\ No newline at end of file
