@@ -8,12 +8,13 @@ class {{cookiecutter.project_metadata.project_name|replace('-', '')|replace('_',
 
     # Agent definitions
     {%- for agent in cookiecutter.structure.agents %}
-    @agent
+    {% if not agent.name == cookiecutter.structure.manager_agent %}@agent{% endif %}
     def {{agent.name}}(self) -> Agent:
         return Agent(
             config=self.agents_config['{{ agent.name }}'],
             tools=[],  # Pass in what tools this agent should have
-            verbose=True
+            verbose=True,
+            {% if agent.allow_delegation %}allow_delegation=True{% endif %}
         )
     {%- endfor %}
 
@@ -32,7 +33,7 @@ class {{cookiecutter.project_metadata.project_name|replace('-', '')|replace('_',
         return Crew(
             agents=self.agents, # Automatically created by the @agent decorator
             tasks=self.tasks, # Automatically created by the @task decorator
-            process=Process.sequential,
+            process=Process.{{cookiecutter.structure.method}},
+            {% if cookiecutter.structure.manager_agent %}manager_agent=self.{{cookiecutter.structure.manager_agent}}(),{% endif %}
             verbose=True,
-            # process=Process.hierarchical, # In case you wanna use that instead https://docs.crewai.com/how-to/Hierarchical/
         )
\ No newline at end of file
