@@ -8,38 +8,41 @@ from agentstack.utils import term_color, get_version, get_framework
 from agentstack import packaging
 from appdirs import user_data_dir
 
+
+def _get_base_dir():
+    """Try to get appropriate directory for storing update file"""
+    try:
+        base_dir = Path(user_data_dir("agentstack", "agency"))
+        # Test if we can write to directory
+        test_file = base_dir / '.test_write_permission'
+        test_file.touch()
+        test_file.unlink()
+    except (RuntimeError, OSError, PermissionError):
+        # In CI or when directory is not writable, use temp directory
+        base_dir = Path(os.getenv('TEMP', '/tmp'))
+    return base_dir
+
+
 AGENTSTACK_PACKAGE = 'agentstack'
+CI_ENV_VARS = [
+    'CI',
+    'GITHUB_ACTIONS',
+    'GITLAB_CI',
+    'TRAVIS',
+    'CIRCLECI',
+    'JENKINS_URL',
+    'TEAMCITY_VERSION',
+]
+
+LAST_CHECK_FILE_PATH = _get_base_dir() / ".cli-last-update"
+INSTALL_PATH = Path(sys.executable).parent.parent
+ENDPOINT_URL = "https://pypi.org/simple"
+CHECK_EVERY = 3600  # hour
 
 
 def _is_ci_environment():
     """Detect if we're running in a CI environment"""
-    ci_env_vars = [
-        'CI',
-        'GITHUB_ACTIONS',
-        'GITLAB_CI',
-        'TRAVIS',
-        'CIRCLECI',
-        'JENKINS_URL',
-        'TEAMCITY_VERSION',
-    ]
-    return any(os.getenv(var) for var in ci_env_vars)
-
-
-# Try to get appropriate directory for storing update file
-try:
-    base_dir = Path(user_data_dir("agentstack", "agency"))
-    # Test if we can write to directory
-    test_file = base_dir / '.test_write_permission'
-    test_file.touch()
-    test_file.unlink()
-except (RuntimeError, OSError, PermissionError):
-    # In CI or when directory is not writable, use temp directory
-    base_dir = Path(os.getenv('TEMP', '/tmp'))
-
-LAST_CHECK_FILE_PATH = base_dir / ".cli-last-update"
-INSTALL_PATH = Path(sys.executable).parent.parent
-ENDPOINT_URL = "https://pypi.org/simple"
-CHECK_EVERY = 3600  # hour
+    return any(os.getenv(var) for var in CI_ENV_VARS)
 
 
 def get_latest_version(package: str) -> Version:
@@ -112,7 +115,7 @@ def check_for_updates(update_requested: bool = False):
     if not update_requested and not should_update():
         return
 
-    print("Checking for updates...\n")
+    print("Checking for updates...")
 
     try:
         latest_version: Version = get_latest_version(AGENTSTACK_PACKAGE)
