@@ -3,31 +3,25 @@ import os, sys
 import unittest
 from pathlib import Path
 import shutil
+from cli_test_utils import run_cli
 
 BASE_PATH = Path(__file__).parent
 
 
 class TestAgentStackCLI(unittest.TestCase):
-    CLI_ENTRY = [
-        sys.executable,
-        "-m",
-        "agentstack.main",
-    ]
-
-    def run_cli(self, *args):
-        """Helper method to run the CLI with arguments."""
-        result = subprocess.run([*self.CLI_ENTRY, *args], capture_output=True, text=True)
-        return result
 
     def test_version(self):
         """Test the --version command."""
-        result = self.run_cli("--version")
+        result = run_cli("--version")
+        print(result.stdout)
+        print(result.stderr)
+        print(result.returncode)
         self.assertEqual(result.returncode, 0)
         self.assertIn("AgentStack CLI version:", result.stdout)
 
     def test_invalid_command(self):
         """Test an invalid command gracefully exits."""
-        result = self.run_cli("invalid_command")
+        result = run_cli("invalid_command")
         self.assertNotEqual(result.returncode, 0)
         self.assertIn("usage:", result.stderr)
 
@@ -35,7 +29,7 @@ class TestAgentStackCLI(unittest.TestCase):
         """Test the 'run' command on an invalid project."""
         test_dir = Path(BASE_PATH / 'tmp/test_project')
         if test_dir.exists():
-            shutil.rmtree(test_dir)
+            shutil.rmtree(test_dir, ignore_errors=True)
         os.makedirs(test_dir)
 
         # Write a basic agentstack.json file
@@ -43,11 +37,11 @@ class TestAgentStackCLI(unittest.TestCase):
             f.write(open(BASE_PATH / 'fixtures/agentstack.json', 'r').read())
 
         os.chdir(test_dir)
-        result = self.run_cli('run')
+        result = run_cli('run')
         self.assertNotEqual(result.returncode, 0)
         self.assertIn("Project validation failed", result.stdout)
 
-        shutil.rmtree(test_dir)
+        shutil.rmtree(test_dir, ignore_errors=True)
 
 
 if __name__ == "__main__":
